import { Component, Element, Event, Method, h, Host, Prop } from "@stencil/core";
import { hideLazyLoadImages, afterSwipe, beforeSwipe, lazyLoadContent, hideAllRevealElements, showAllRevealElements, } from '@deckdeckgo/slide-utils';
/**
 * @slot title - A title
 * @slot content - A content
 * @slot notes - Some notes related to this slide
 * @slot actions - Custom actions for this slide
 * @slot background - A custom background for this slide
 * @slot header - A custom header for this slide
 * @slot footer - A custom footer for this slide
 */
export class DeckdeckgoSlideTitle {
  constructor() {
    /**
     * If you define a background for the all deck but, a specific one for this slide, set this option to true
     */
    this.customBackground = false;
    /**
     * If you provide actions for the all deck but, a specific one for this slide, set this option to true
     */
    this.customActions = false;
  }
  async componentDidLoad() {
    await hideLazyLoadImages(this.el);
    this.slideDidLoad.emit();
  }
  beforeSwipe(enter, reveal) {
    return beforeSwipe(this.el, enter, reveal);
  }
  afterSwipe() {
    return afterSwipe();
  }
  lazyLoadContent() {
    return lazyLoadContent(this.el);
  }
  revealContent() {
    return showAllRevealElements(this.el);
  }
  hideContent() {
    return hideAllRevealElements(this.el);
  }
  render() {
    return (h(Host, { class: { 'deckgo-slide-container': true } },
      h("div", { class: "deckgo-slide" },
        h("slot", { name: "title" }),
        h("slot", { name: "content" }),
        h("slot", { name: "notes" }),
        h("slot", { name: "actions" }),
        h("slot", { name: "background" }),
        h("slot", { name: "header" }),
        h("slot", { name: "footer" }))));
  }
  static get is() { return "deckgo-slide-title"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["deckdeckgo-slide-title.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["deckdeckgo-slide-title.css"]
  }; }
  static get properties() { return {
    "customBackground": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If you define a background for the all deck but, a specific one for this slide, set this option to true"
      },
      "attribute": "custom-background",
      "reflect": true,
      "defaultValue": "false"
    },
    "customActions": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If you provide actions for the all deck but, a specific one for this slide, set this option to true"
      },
      "attribute": "custom-actions",
      "reflect": true,
      "defaultValue": "false"
    }
  }; }
  static get events() { return [{
      "method": "slideDidLoad",
      "name": "slideDidLoad",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Triggered when the slide is loaded"
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }]; }
  static get methods() { return {
    "beforeSwipe": {
      "complexType": {
        "signature": "(enter: boolean, reveal: boolean) => Promise<boolean>",
        "parameters": [{
            "tags": [],
            "text": ""
          }, {
            "tags": [],
            "text": ""
          }],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<boolean>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "afterSwipe": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "lazyLoadContent": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "revealContent": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "hideContent": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
}
